import { Label, Loader } from '@ui5/webcomponents-react';
import { useStylesheet } from '@ui5/webcomponents-react-base';
import { clsx } from 'clsx';
import React, { Component, forwardRef } from 'react';
import { ResponsiveContainer } from 'recharts';
import { classNames, styleData } from './ChartContainer.module.css.js';
const loaderStyles = {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0
};
class ErrorBoundary extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            errorCount: 0
        };
    }
    componentDidCatch() {
        if (this.state.errorCount < 3) {
            this.setState((old) => ({ ...old, errorCount: old.errorCount + 1 }));
        }
    }
    render() {
        if (this.state.errorCount >= 3) {
            return React.createElement(Label, null, "Sorry, something went wrong while rendering this chart!");
        }
        return this.props.children;
    }
}
const ChartContainer = forwardRef((props, ref) => {
    const { Placeholder, loading = false, dataset, className, slot, children, resizeDebounce, ...rest } = props;
    useStylesheet(styleData, ChartContainer.displayName);
    return (React.createElement("div", { ref: ref, className: clsx(classNames.container, className), slot: slot, ...rest }, dataset?.length > 0 ? (React.createElement(React.Fragment, null,
        loading && React.createElement(Loader, { style: loaderStyles }),
        React.createElement(ErrorBoundary, null,
            React.createElement(ResponsiveContainer, { debounce: resizeDebounce }, children)))) : (React.createElement(Placeholder, null))));
});
ChartContainer.displayName = 'ChartContainer';
export { ChartContainer };
